FirestoreQueryDocumentSnapshot<Model> class
abstract
Properties
-
data
→ Model
-
Retrieves all fields in the document as an Object.
no setteroverride
-
exists
→ bool
-
Property of the DocumentSnapshot that signals whether or not the data exists.
True if the document exists.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ String
-
Property of the DocumentSnapshot that provides the document's ID.
no setterinherited
-
metadata
→ SnapshotMetadata
-
Metadata about this snapshot, concerning its source and if it has
local modifications.
no setterinherited
-
reference
→ FirestoreDocumentReference<Model, FirestoreDocumentSnapshot<Model>>
-
The reference for this document.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
snapshot
→ QueryDocumentSnapshot<Model>
-
The original
QueryDocumentSnapshot returned by Firebase.
no setteroverride
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited